diff --git a/Dockerfile b/Dockerfile
new file mode 100644
index 000000000000..4a07fe1e5c33
--- /dev/null
+++ b/Dockerfile
@@ -0,0 +1,30 @@
+FROM debian:jessie
+MAINTAINER amnesia@boum.org
+
+ADD setup_container /root/setup_container
+RUN bash /root/setup_container
+
+RUN	apt-get update &&						\
+	apt-get install --assume-yes --no-install-recommends		\
+	--allow-unauthenticated						\
+	bash								\
+	cpio								\
+	dpkg-dev							\
+	eatmydata/squeeze-backports					\
+	git								\
+	ikiwiki								\
+	intltool							\
+	libdpkg-perl							\
+	libyaml-perl							\
+	libyaml-syck-perl						\
+	live-build/builder-wheezy					\
+	perlmagick							\
+	po4a								\
+	syslinux							\
+	time								\
+	wget								\
+	whois
+
+WORKDIR /root/tails
+ENTRYPOINT ["/bin/bash", "-l", "-c"]
+CMD []
diff --git a/Makefile b/Makefile
new file mode 100644
index 000000000000..45f7bb59f975
--- /dev/null
+++ b/Makefile
@@ -0,0 +1,14 @@
+CURRENT_BRANCH := $(shell git rev-parse --abbrev-ref HEAD)
+DOCKER_IMAGE_NAME := "tails$(if $(CURRENT_BRANCH),-$(CURRENT_BRANCH))"
+DOCKER_MOUNT := "$(shell pwd):/root/tails"
+DOCKER_RUN := docker run --rm --privileged -v $(DOCKER_MOUNT) -t $(DOCKER_IMAGE_NAME)
+
+default: all
+
+all: env image
+
+image:
+	$(DOCKER_RUN) "lb clean --all && lb config && lb build"
+
+env:
+	docker build -t "$(DOCKER_IMAGE_NAME)" .
diff --git a/setup_container b/setup_container
new file mode 100644
index 000000000000..0a294f23efe6
--- /dev/null
+++ b/setup_container
@@ -0,0 +1,22 @@
+cat <<EOF >> /etc/apt/sources.list
+
+deb http://http.debian.net/debian unstable main
+deb-src http://http.debian.net/debian unstable main
+
+deb http://backports.debian.org/debian-backports squeeze-backports main
+deb http://deb.tails.boum.org/ builder-wheezy main
+EOF
+
+cat <<EOF > /etc/apt/preferences.d/tails.pref
+Package: *
+Pin: release a=unstable
+Pin-Priority: 500
+EOF
+
+mkdir /etc/live
+cat <<EOF > /etc/live/build.conf
+LB_PARENT_MIRROR_BINARY="http://ftp.us.debian.org/debian/"
+LB_MIRROR_BINARY="http://ftp.us.debian.org/debian/"
+EOF
+
+echo -e '\nexport TAILS_BUILD_OPTIONS="noproxy"' >> /etc/profile
